==> mosh_1.3.2.orig.tar.gz: mosh-1.3.2/src/tests/test_utils.cc <==
/*
    Mosh: the mobile shell
    Copyright 2012 Keith Winstein

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

    In addition, as a special exception, the copyright holders give
    permission to link the code of portions of this program with the
    OpenSSL library under certain conditions as described in each
    individual source file, and distribute linked combinations including
    the two.

    You must obey the GNU General Public License in all respects for all
    of the code used other than OpenSSL. If you modify file(s) with this
    exception, you may extend this exception to your version of the
    file(s), but you are not obligated to do so. If you do not wish to do
    so, delete this exception statement from your version. If you delete
    this exception statement from all source files in the program, then
    also delete it here.
*/

#include <stdio.h>

#include "test_utils.h"

void hexdump( const void *buf, size_t len, const char *name ) {
  const unsigned char *data = (const unsigned char *) buf;
  printf( DUMP_NAME_FMT, name );
  for ( size_t i = 0; i < len; i++ ) {
    printf( "%02x", data[ i ] );
  }
  printf( "\n" );
}

void hexdump( const Crypto::AlignedBuffer &buf, const char *name ) {
  hexdump( buf.data(), buf.len(), name );
}

void hexdump( const std::string &buf, const char *name ) {
  hexdump( buf.data(), buf.size(), name );
}

==> mosh_1.4.0.orig.tar.gz: mosh-1.4.0/src/tests/test_utils.cc <==
/*
    Mosh: the mobile shell
    Copyright 2012 Keith Winstein

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

    In addition, as a special exception, the copyright holders give
    permission to link the code of portions of this program with the
    OpenSSL library under certain conditions as described in each
    individual source file, and distribute linked combinations including
    the two.

    You must obey the GNU General Public License in all respects for all
    of the code used other than OpenSSL. If you modify file(s) with this
    exception, you may extend this exception to your version of the
    file(s), but you are not obligated to do so. If you do not wish to do
    so, delete this exception statement from your version. If you delete
    this exception statement from all source files in the program, then
    also delete it here.
*/

#include <stdio.h>

#include "test_utils.h"

void hexdump( const void *buf, size_t len, const char *name ) {
  const unsigned char *data = (const unsigned char *) buf;
  printf( DUMP_NAME_FMT, name );
  for ( size_t i = 0; i < len; i++ ) {
    // Although data[i] is an unsigned char, it will be promoted to a signed int
    // when passed as an argument. Explicitly cast it back to an unsigned type
    // so it can be printed in hex.
    printf( "%02x", static_cast<unsigned>( data[ i ] ) );
  }
  printf( "\n" );
}

void hexdump( const Crypto::AlignedBuffer &buf, const char *name ) {
  hexdump( buf.data(), buf.len(), name );
}

void hexdump( const std::string &buf, const char *name ) {
  hexdump( buf.data(), buf.size(), name );
}
